package physbeans.editors;

import java.util.*;
import java.awt.*;
import java.awt.font.*;
import java.awt.geom.*;
import java.beans.*;
import physbeans.math.*;
import physbeans.model.*;

/**
 * Property editor for Color array.
 */
public class ArrayOfColorEditor extends PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current Color array.
   */
  public String getAsText() {
    return null;
  }
  
  /**
   * Returns a string with java code that initializes a Point2dVector.
   */
  public String getJavaInitializationString() {
    Color[] value = (Color[]) getValue();
    
    int dim = value.length;
    String result = "new Color[]{\n";
    
    for (int i=0; i<dim - 1; i++) {
      Color c = value[i];
      result += "new Color(" + c.getRed() + ", " + c.getGreen() + ", "
          + c.getBlue() + "),\n";
    }
    
    Color c = value[dim - 1];
    result += "new Color(" + c.getRed() + ", " + c.getGreen() + ", "
          + c.getBlue() + ")}";
    
    return result;
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new ArrayOfColorCustomEditor(this);
  }
  
  /**
   * Returns true, if the property can be painted.
   */
  public boolean isPaintable() {
    return true;
  }
  
  /**
   * Paints a Color bar.
   */
  public void paintValue(Graphics g, Rectangle box) {
    Graphics2D g2 = (Graphics2D) g;
    Color[] values = (Color[]) getValue();
    if (values == null) {  // not yet initialised
      return;
    }
    
    int dim = values.length;   
    double w1 = (box.getWidth() - 2.0)/dim;
    double h1 = box.getHeight() - 2.0;
    Rectangle rect1 = new Rectangle();
    
    g2.setColor(Color.white);
    g2.fill(box);
    for (int i = 0; i < dim; i++) {
      rect1.setRect(1.0 + i*w1, 1.0, w1, h1);
      g2.setColor(values[i]);
      g2.fill(rect1);
    }
  }
}
