package physbeans.editors;

import java.util.*;
import java.awt.*;

import physbeans.model.*;

/**
 * Property editor for BoundedRealModel
 */
public class BoundedRealModelEditor extends java.beans.PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current BoundedRealModel.
   */
  public String getAsText() {
    if (getValue() == null)
      return "null";
    
    BoundedRealModel model = (BoundedRealModel) getValue();
    return "[" + model.getMinimum() + "," + model.getValue() + ","
        + model.getMaximum() + "]";
  }
  
  /**
   * Reads the value of the property by parsing a string.
   */
  public void setAsText(String text) throws IllegalArgumentException {
    if (text.equals("null") || text.equals("")) {
      setValue(null);
      return;
    }
    
    BoundedRealModel model = null;
    StringTokenizer toc = new StringTokenizer(text, "[] ,;");
    try {
      if (toc.countTokens() == 3) {
        double min = Double.parseDouble(toc.nextToken());
        double val = Double.parseDouble(toc.nextToken());
        double max = Double.parseDouble(toc.nextToken());
        model = new BoundedRealModel(min, val, max);
      } else {
        // badly formed text
        wrongFormat(text);
      }
    } catch (NumberFormatException e) {
      wrongFormat(text);
    }
    
    setValue(model);
  }
  
  /**
   * Throws an exception if the text has a wrong format.
   */
  protected void wrongFormat(String text) throws IllegalArgumentException {
    throw new IllegalArgumentException("wrong format in " + text);
  }
  
  /**
   * Returns a string with java code that initializes a BoundedRealModel.
   */
  public String getJavaInitializationString() {
    BoundedRealModel model = (BoundedRealModel) getValue();
    double min = model.getMinimum();
    double val = model.getValue();
    double max = model.getMaximum();
    return "new BoundedRealModel(" + min + "," + val + "," + max + ")";
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new BoundedRealModelCustomEditor(this);
  }
}
