package physbeans.editors;

import java.util.*;
import java.awt.*;
import java.beans.*;
import physbeans.math.*;

/**
 * Property editor for DVector.
 */
public class DVectorEditor extends PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current DVector.
   */
  public String getAsText() {
    DVector v = (DVector) getValue();
    
    if (v == null) {
      return "null";
    } else {
      return v.toString();
    }
  }
  
  /**
   * Reads the value of the property by parsing a string.
   */
  public void setAsText(String text) throws IllegalArgumentException {
    if (text.equals("null") || text.equals("")) {
      setValue(null);
      return;
    }
    
    setValue(DVector.valueOf(text));
  }
  
  /**
   * Returns a string with java code that initializes a DVector.
   */
  public String getJavaInitializationString() {
    DVector v = (DVector) getValue();
    return "DVector.valueOf(\"" + v.toString() + "\")";
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new DVectorCustomEditor(this);
  }
  
}
