package physbeans.editors;

import java.util.*;
import java.awt.*;
import java.awt.font.*;
import java.awt.geom.*;
import java.beans.*;
import physbeans.math.*;
import physbeans.model.*;

/**
 * Property editor for Point2dVector.
 */
public class Point2dVectorEditor extends PropertyEditorSupport {
  
  /**
   * Returns a string that represents the current DVector.
   */
  public String getAsText() {
    return null;
  }
  
  /**
   * Returns a string with java code that initializes a Point2dVector.
   */
  public String getJavaInitializationString() {
    Point2dVector value = (Point2dVector) getValue();
    DVector xValues = value.getXCoords();
    DVector yValues = value.getYCoords();
    
    // create strings for initialisation of the x and y arrays
    String xString = "{";
    String yString = "{";
    int dim = value.size();
    for (int i=0; i<dim - 1; i++) {
      xString +=  xValues.get(i) + ",";
      yString +=  yValues.get(i) + ",";
    }
    xString +=  xValues.get(dim - 1) + "}";
    yString +=  yValues.get(dim - 1) + "}";
    
    String result = "new Point2dVector(new double[]" + xString
        + ", new double[]" + yString + ")";
    
    return result;
  }
  
  /**
   * Returns true if a custom editor exists.
   */
  public boolean supportsCustomEditor() {
    return true;
  }
  
  /**
   * Returns an instance of a new custom editor.
   */
  public Component getCustomEditor() {
    return new Point2dVectorCustomEditor(this);
  }
  
  /**
   * Returns true, if the property can be painted.
   */
  public boolean isPaintable() {
    return true;
  }
  
  /**
   * Paints a representation of a Point2dVector.
   */
  public void paintValue(Graphics g, Rectangle box) {
    Graphics2D g2 = (Graphics2D) g;
    Point2dVector values = (Point2dVector) getValue();
    if (values == null) {  // not yet initialised
      return;
    }
    double[] xValues = values.getXCoords().getArray();
    double[] yValues = values.getYCoords().getArray();
    
    StringBuffer s = new StringBuffer();
    
    if (xValues.length > 0) {
      s.append("(");
      s.append(xValues[0]);
      s.append(",");
      s.append(yValues[0]);
      s.append("), ...");
    } else {
      s.append("()");
    }
    
    g2.setColor(Color.white);
    g2.fill(box);
    g2.setColor(Color.black);
    FontRenderContext context = g2.getFontRenderContext();
    Rectangle2D stringBounds = g2.getFont().getStringBounds(
        s.toString(), context);
    double w = stringBounds.getWidth();
    double x = box.x;
    if (w < box.width) x += (box.width - w) / 2;
    double ascent = -stringBounds.getY();
    double y = box.y
        + (box.height - stringBounds.getHeight()) / 2 + ascent;
    g2.drawString(s.toString(), (float)x, (float)y);
  }
}
