package physbeans.event;

import java.util.*;

/**
 * class to simplify use of timer stop events
 */
public class TimerStopSupport {
  
  /** list of all observer objects listening to this timer stopping */
  protected Vector<TimerStopListener> listeners;
  
  /** Creates a new instance of TimerSupport */
  public TimerStopSupport() {
    // prepare for listeners
    listeners = new Vector<TimerStopListener>();
  }
  
  /**
   * register a TimerStopListener
   */
  public synchronized void addTimerStopListener(TimerStopListener sl) {
    listeners.addElement(sl);
  }
  
  /**
   * de-register a TimerStopListener
   */
  public synchronized void removeTimerStopListener(TimerStopListener sl) {
    listeners.removeElement(sl);
  }
  
 
  /**
   * inform all TimerStopListeners that they should restart
   */
  public void fireStopEvent(StopEvent e) {
    Vector l;
    
    // clone the list of listeners so that delivery and simultaneous
    // addition/deletion of listeners don't interfere
    synchronized (this) {
      l = (Vector) listeners.clone();
    }
    
    for (int i = 0; i < l.size(); i++) {
      ((TimerStopListener) l.elementAt(i)).stop(e);
    }
  }
}
