package physbeans.event;

import java.util.*;

/**
 * class to simplify use of timer events
 */
public class TimerSupport {
  
  /** list of all observer objects listening to this timer */
  protected Vector<TimerListener> listeners;
  
  /** Creates a new instance of TimerSupport */
  public TimerSupport() {
    // prepare for listeners
    listeners = new Vector<TimerListener>();
  }
  
  /**
   * register a TimerListener
   */
  public synchronized void addTimerListener(TimerListener sl) {
    listeners.addElement(sl);
  }
  
  /**
   * de-register a TimerListener
   */
  public synchronized void removeTimerListener(TimerListener sl) {
    listeners.removeElement(sl);
  }
  
  /**
   * inform all TimerListeners that the next time step has been reached
   */
  public void fireNextStepEvent(NextStepEvent e) {
    Vector l;
    
    // clone the list of listeners so that delivery and simultaneous
    // addition/deletion of listeners don't interfere
    synchronized (this) {
      l = (Vector) listeners.clone();
    }
    
    for (int i = 0; i < l.size(); i++) {
      ((TimerListener) l.elementAt(i)).nextStep(e);
    }
  }

  /**
   * inform all TimerListeners that they should restart
   */
  public void fireRestartEvent(RestartEvent e) {
    Vector l;
    
    // clone the list of listeners so that delivery and simultaneous
    // addition/deletion of listeners don't interfere
    synchronized (this) {
      l = (Vector) listeners.clone();
    }
    
    for (int i = 0; i < l.size(); i++) {
      ((TimerListener) l.elementAt(i)).restart(e);
    }
  }
}
