package physbeans.func;

/**
 * Function that selects some of the input signals and reorders them.
 * <p>Used as interface between blocks that use different vector lengths for
 * switching signals.
 */
public class BooleanSelector extends GenericFunction {
  
  protected boolean[] in;
  protected boolean[] out;
  
  protected int[] index;
  
  /**
   * Creates standard BooleanSelector.
   */
  public BooleanSelector() {
    super();
    in = new boolean[2];
    out = new boolean[2];
    index = new int[]{0, 1};
  }
  
  /**
   * Gets array of index values.<br>
   * index[i] = j   <=> input j is connected to output i
   */
  public int[] getIndex() {
    return this.index;
  }
  
  /**
   * Sets array of index values.<br>
   * index[i] = j   <=> input j is connected to output i
   */
  public void setIndex(int[] index) {
    this.index = index;
  }
  
  /**
   * Sets input to new values.
   */
  public void setInputValues(boolean[] vals) {
    in = vals;
    if (autoTriggered) {
      inform();
    }
  }
  
  /**
   * Gets output values.
   */
  public boolean[] getOutputValues() {
    return (boolean[]) out;
  }
  
  /**
   * Gets length of output vector.
   */
  public int getOutputLength() {
    return out.length;
  }
  
  /**
   * Sets length of output vector.
   */
  public void setOutputLength(int n){
    out = new boolean[n];
  }
  
  /**
   * Copies selected values from in to out.
   */
  protected void compute() {
    int len = Math.min(out.length, index.length);  // cut off oversized index array
    for (int i = 0; i < len; i++) {
      out[i] = in[index[i]];
    }
  }
  
}
