package physbeans.func;

import java.beans.*;
import physbeans.math.*;

/**
 * Describes a function of 1 input value with m output values (vector function)
 */
public abstract class Generic1dFunction extends GenericNdFunction {

  /**
   * default constructor: 2 out
   */
  public Generic1dFunction() {
    this(2);
  }

  /**
   * general constructor with m output values
   */
  public Generic1dFunction(int nOut) {
    super(1, nOut);
  }

  // functions to simplify working with a single input value
  /** is fixed to 1!  */
  public void setInputLength(int size) {
    super.setInputLength(1);
  }

  /**
   * Sets the only input value.
   * Triggers function if autoTriggered.
   */
  public void setInputValue(double in) {
    setInputValues(0, in);
  }

  /**
   * Gets the only input value.
   * Internal conveniance function to simplify access.
   */
  protected double getInputValue() {
    return getInputValues(0);
  }

  /**
   * Vector argument is just a scalar in disguise.
   */
  protected DVector computeFunction(DVector in) {
    return computeFunction(in.get(0));
  }

  abstract public DVector computeFunction(double t);
}
