package physbeans.func;

import physbeans.func.GenericVectorFunction;
import physbeans.math.*;
import java.io.*;

/**
 * Constant vector of double values,
 * given by minimal/maximal value and number of values.
 */
public class StrideVector extends GenericVectorFunction implements Serializable {
  
  /** first (minimal) value   */
  protected double minVal;
  
  /** last (maximal) value */
  protected double maxVal;
  
  /** create default StrideVector */
  public StrideVector() {
    super(0, 1, 100);
    minVal = 0.0;
    maxVal = 10.0;
    createStrideVector();
  }
  
  /**
   * gets first (minimal) value
   */
  public double getMinVal() {
    return this.minVal;
  }
  
  /**
   * sets first (minimal) value
   */
  public void setMinVal(double minVal) {
    this.minVal = minVal;
    createStrideVector();
  }
  
  /**
   * gets last (maximal) value
   */
  public double getMaxVal() {
    return this.maxVal;
  }
  
  /**
   * sets last (maximal) value
   */
  public void setMaxVal(double maxVal) {
    this.maxVal = maxVal;
    createStrideVector();
  }
  
  /**
   * Sets the number of output values.
   */
  public void setOutputSize(int size) {
    if (size >= 0) {
      super.setOutputSize(size);
      createStrideVector();
    }
  }
  
  /**
   * simply returns (constant precomputed) output vector.
   */
  protected void compute() {
  }
  
  protected void createStrideVector() {
    int n = getOutputLength(0);
    DVector out = outputValues[0];
    double increment = (maxVal - minVal)/(n - 1);
    
    if (n > 0) {
      out.set(0, minVal);
      
      for (int i = 1; i < n; i++) {
        out.set(i, out.get(i-1) + increment);
      }
    }
  }
  
}
