package physbeans.func;

import physbeans.math.*;
import physbeans.model.*;
import java.io.*;

/**
 * Periodic function describing a trapezoid pulse between 0 and 1.
 * External parameter is the pulse width.
 */
public class TrapezoidFunction extends PeriodicPiecewiseLinearFunction
                implements Serializable, PeriodicFunctionWithParameter {
  
  /** Holds value of property pulseWidth. */
  protected double pulseWidth;
  
  /** Creates a new instance of SquareFunction */
  public TrapezoidFunction() {
    super();
    setPulseWidth(0.5);
  }
  
  /**
   * Gets the pulse width.
   * It is given as relative value, between 0 and 1.
   */
  public double getPulseWidth() {
    return pulseWidth;
  }
  
  /**
   * Sets the pulse width.
   * Input value is clamped to lie between 0 and 1.
   */
  public void setPulseWidth(double p) {
    if (p != 1.0) {
      p = p - Math.floor(p);
    }
    pulseWidth = p;
    setCornerPoints();
  }
  
  /**
   * Sets the period T.
   */
  public void setPeriod(double period) {
    super.setPeriod(period);
    setCornerPoints();
  }
  
  /*
   * compute corner points from pulse width and period.
   */
  protected void setCornerPoints() {
    double p = pulseWidth/4.0;
    x = new DVector(p, 0.5 - p, 0.5 + p, 1.0 - p);
    y = new DVector(0.0, 1.0, 1.0, 0.0);
  }
  
  /**
   * Gets the parameter value.
   */
  public double getParameter() {
    return getPulseWidth();
  }
  
  /**
   * Sets the parameter
   */
  public void setParameter(double p) {
    setPulseWidth(p);
  }
}
