package physbeans.inout;

import java.awt.*;
import javax.swing.*;
import java.io.*;
import java.beans.*;

/**
 * Line with title text and NumericTextField<br>
 * allows justification of number field
 */
public class NumericTextLine extends PhysicsPanel implements Serializable {
  protected JLabel titleLabel;
  protected NumericTextField ntf;
  
  /**
   * constructor with default values
   */
  public NumericTextLine() {
    this(0.0, 8, 3, "Description", "Unit", "Title", 0);
  }
  
  public NumericTextLine(double val, int cols, int prec,
      String desc, String unit, String title, int offset) {
    super();
    setLayout(new BorderLayout());
    setBorder(BorderFactory.createEmptyBorder(4,4,4,4));
    
    // add title
    titleLabel = new JLabel(title, JLabel.LEFT);
    titleLabel.setBorder(BorderFactory.createEmptyBorder(0,0,0,4));
    titleLabel.setFont(null);
    
    // add NumericTextField
    ntf = new NumericTextField(val, cols, prec, desc, unit);
    setOffset(offset);
    
    // build GUI
    add(titleLabel, BorderLayout.WEST);
    add(ntf, BorderLayout.EAST);
    
  }
  
  
  /**
   * gets number of columns for text field
   */
  public int getColumns() {
    return ntf.getColumns();
  }
  
  /**
   * gets description string
   */
  public String getDescription() {
    return ntf.getDescription();
  }
  
  /**
   * gets size of offset at right margin. <br>
   * used for justification of number fields
   */
  public int getOffset() {
    return ntf.getOffset();
  }
  
  /**
   * gets number of displayed digits
   */
  public int getPrecision() {
    return ntf.getPrecision();
  }
  
  /**
   * gets title string
   */
  public String getTitle() {
    return titleLabel.getText();
  }
  
  /**
   * gets string after number field (unit)
   */
  public String getUnit() {
    return ntf.getUnit();
  }
  
  /**
   * gets numeric value
   */
  public double getValue() {
    return ntf.getValue();
  }
  
  /**
   * true if number can be edited
   */
  public boolean isEditable() {
    return ntf.isEditable();
  }
  
  /**
   * sets foreground color
   */
  public void setForeground(Color c) {
    super.setForeground(c);
    if (ntf != null) {
      ntf.setForeground(c);
    }
  }
  
  /**
   * sets number of columns for text field
   */
  public void setColumns(int col) {
    ntf.setColumns(col);
  }
  
  /**
   * sets description string
   */
  public void setDescription(String description) {
    ntf.setDescription(description);
  }
  
  /**
   *  sets value of editable flag
   */
  public void setEditable(boolean flag) {
    ntf.setEditable(flag);
  }
  
  /**
   * sets size of offset at right margin. <br>
   * used for justification of number fields
   */
  public void setOffset(int offset) {
    ntf.setOffset(offset);
  }
  
  /**
   * sets number of displayed digits
   */
  public void setPrecision(int p) {
    ntf.setPrecision(p);
  }
  
  /**
   * sets title string
   */
  public void setTitle(String title) {
    titleLabel.setText(title);
  }
  
  /**
   * sets string after number field (unit)
   */
  public void setUnit(String unit) {
    ntf.setUnit(unit);
  }
  
  /** sets TextField to value without sending an event. <br>
   *  uses internal precision
   */
  void setValueInternally(double val) {
    // package access so that TextSlider can use it
    ntf.setValueInternally(val);
  }
  
  /**
   * sets numeric value
   */
  public void setValue(double d) {
    ntf.setValue(d);
  }
  
  /**
   * conveniance function: allows to use the first element of a vector
   * instead of a scalar for input
   */
  public void setValueFromVector(double[] v) {
    setValue(v[0]);
  }
   
  // use property change support of ntf
  
  public synchronized void addPropertyChangeListener(PropertyChangeListener listener) {
    ntf.addPropertyChangeListener(listener);
  }
  
  public void firePropertyChange(String propertyName, Object oldValue, Object newValue) {
    if (ntf != null) { // careful: this is called by some parent at init time
      ntf.firePropertyChange(propertyName, oldValue, newValue);
    }
  }
  
  public synchronized void removePropertyChangeListener(PropertyChangeListener listener) {
    ntf.removePropertyChangeListener(listener);
  }
  
  public synchronized void addVetoableChangeListener(VetoableChangeListener listener) {
    ntf.addVetoableChangeListener(listener);
  }
  
  public void fireVetoableChange(String name, Object oldVal, Object newVal)
  throws PropertyVetoException {
    if (ntf != null) { // careful: this is called by some parent at init time
      ntf.fireVetoableChange(name, oldVal, newVal);
    }
  }
  
  public synchronized void removeVetoableChangeListener(VetoableChangeListener listener) {
    ntf.removeVetoableChangeListener(listener);
  }
  
}
