package physbeans.math;

import physbeans.model.*;

/**
 * Bulirsch-Stoer interpolation
 *
 * @author Didier H. Besset
 * adapted to PhysBeans   PJ
 */
public class BulirschStoerInterpolator extends NevilleInterpolator {
  
  /**
   * Constructor method.
   * @param pts Point2dVector
   */
  public BulirschStoerInterpolator(Point2dVector pts) {
    super(pts);
  }

  /**
   * @param m int
   * @param n int
   * @param x double
   */
  protected void computeNextDifference( int m, int n, double x) {
    double ratio = ( points.getX(n) - x) * rightErrors[n]
        / ( points.getX(n + m + 1) - x);
    double diff = ( leftErrors[n+1] - rightErrors[n])
    / ( ratio - leftErrors[n+1]);
    if( Double.isNaN( diff) ) {
      diff = 0;
    }
    rightErrors[n] = leftErrors[n+1] * diff;
    leftErrors[n] = ratio * diff;
  }
}