package physbeans.model;

import physbeans.phys.*;


/**
 * Vector defining a number of states.<br>
 * States are labelled as integer values from 0 to #states - 1, the start value
 * is 0.
 */
public class StateVector extends PhysModel {
  
  protected int[] state;
  protected int[] stateCount;
  
  /** Creates a new instance of StateVector */
  public StateVector() {
    super();
    state = new int[10];
    stateCount = new int[4];
    initStates();
  }
  
  /**
   * Gets the number of elements.
   */
  public int getNumberOfElements() {
    return state.length;
  }
  
  /**
   * Sets the number of elements.
   */
  public void setNumberOfElements(int n) {
    state = new int[n];
    initStates();
    trigger();
  }
  
  /**
   * Gets the number of states.
   */
  public int getNumberOfStates() {
    return stateCount.length;
  }
  
  /**
   * Sets the number of states.
   */
  public void setNumberOfStates(int n) {
    stateCount = new int[n];
    initStates();
    trigger();
  }
  
  /**
   * Gets the population counts of the states.
   */
  public int[] getStateCounts() {
    return stateCount;
  }
  
  /**
   * Gets the vector of states.
   */
  public int[] getStates() {
    return state;
  }
  
  /**
   * Gets the state of element nr.
   */
  public int getState(int nr) {
    return state[nr];
  }
  
  /**
   * Changes the state of element nr to newState, if newState is valid.
   */
  public void setState(int nr, int newState) {
    if ((newState < 0) || (newState >= stateCount.length)) {
      return;
    }
    
    stateCount[state[nr]]--;
    state[nr] = newState;
    stateCount[state[nr]]++;
    
    trigger();
  }
  
  /**
   * Sets all elements into the initial state.
   */
  public void restart() {
    initStates();
    trigger();
  }
  
  /**
   * Initialise internal values.
   */
  protected void initStates() {
    for (int i = 0; i < state.length; i++) {
      state[i] = 0;
    }
    
    stateCount[0] = state.length;
    for (int i = 1; i < stateCount.length; i++) {
      stateCount[i] = 0;
    }
  }
}
