package physbeans.phys;

import physbeans.func.*;
import physbeans.math.*;

/**
 * Function to measure the backforce of a linear mass-spring system to
 * the basement.
 *
 * Assumes that the first mass (index 0) sits on the ground.
 */
public class BasementForce extends GenericNdFunction {

  protected LinearChainOscillator system;

  protected DVector computeFunction(DVector in) {
    double c1 = system.getSpringStiffnesses().get(0);   // lowest spring
    double b1 = system.getDamperCoefficients().get(0);  // lowest damper

    int dim = in.getDimension() / 2;
    double x1 = in.get(0);
    double v1 = in.get(dim);

    return new DVector(c1*x1 + b1*v1);
  }

  /**
   * Gets the LinearChainOscillator system that is measured.
   */
  public LinearChainOscillator getSystem() {
    return system;
  }

  /**
   * Sets the LinearChainOscillator system that is measured.
   */
 public void setSystem(LinearChainOscillator s) {
    system = s;
    inform();
  }
}
