package physbeans.phys;

import physbeans.math.*;
import java.awt.*;

/**
 * A simple circular wall .
 */
public class CircularWall extends WaveWall {
  
  protected DVector vc;
  protected double r0, dr;
  
  /** Creates a new instance of SimpleWall */
  public CircularWall() {
    super();
    vc = new DVector(0.0, 0.0);
    r0 = 1.0;
    dr = 0.1;
  }
  
  protected void setGrid() {
    if ((field == null) || (grid == null)) {
      return;
    }
    
    initGrid();
    
    int sx = field.getGridSizeX();
    int sy = field.getGridSizeY();
    
    Point pc = field.getIndex(vc);
    int pri = field.getIndexForX(vc.x() + r0) - pc.x;   // r0 in pixel
    int pro = field.getIndexForX(vc.x() + r0 + dr) - pc.x;   // r0+dr in pixel
    
    if (pri < 0) return;        // the wall is larger tan the (proper) grid
    if (pro < 0) {              // the outer wall reaches the boundary
      pro = pri + 1;
    }
    
    double r;
    for (int x = 0; x < sx; x++) {
      for (int y = 0; y < sy; y++) {
        r = Math.hypot(x - pc.x, y - pc.y);
        if ((r >= pri) && (r <= pro)) {
          grid[y][x] = 1.0;
        }
      }
    }
    
    trigger();
  }
  
  /**
   * Gets the (inner) radius of the wall.
   */
  public double getRadius() {
    return r0;
  }
  
  /**
   * Sets the (inner) radius of the wall.
   */
  public void setRadius(double r) {
    r0 = r;
    setGrid();
  }
  
  /**
   * Gets the width of the wall.
   */
  public double getWidth() {
    return dr;
  }
  
  /**
   * Sets the width of the wall.
   */
  public void setWidth(double dr) {
    this.dr = dr;
    setGrid();
  }
  
  /**
   * Gets the coordinates of the center point.
   */
  public DVector getCenter() {
    return vc;
  }
  
  /**
   * Sets the coordinates of the center point.
   */
  public void setCenter(DVector v) {
    vc = v;
    setGrid();
  }
}
