package physbeans.phys;

/**
 * Splits the grid vertically or horizontally and defines two different media
 * (i.e. different wave velocities) on both sides).
 */
public class HalfSpaceWaveMedium extends WaveMedium {
  
  protected double cUp, cLow;
  protected boolean horizontal;
  protected double pos;
  
  /** Creates a new instance of HalfSpaceWaveMedium */
  public HalfSpaceWaveMedium() {
    super();
    cUp = 0.7;
    cLow = 1.0;
    horizontal = false;
    pos = 0.0;
  }
  
  protected void setGrid() {
    if ((field == null) || (grid == null)) {
      return;
    }
    
    initGrid();
    
    if (horizontal) {
      int yb = field.getIndexForY(pos);
      
      for (int y = 0; y < yb; y++) {
        for (int x = 0; x < field.getGridSizeX(); x++) {
          grid[y][x] = cLow*cLow;
        }
      }
      
      for (int y = yb; y < field.getGridSizeY(); y++) {
        for (int x = 0; x < field.getGridSizeX(); x++) {
          grid[y][x] = cUp*cUp;
        }
      }
      
    } else {
      int xb = field.getIndexForX(pos);
      
      for (int x = 0; x < xb; x++) {
        for (int y = 0; y < field.getGridSizeY(); y++) {
          grid[y][x] = cLow*cLow;
        }
      }
      
      for (int x = xb; x < field.getGridSizeX(); x++) {
        for (int y = 0; y < field.getGridSizeY(); y++) {
          grid[y][x] = cUp*cUp;
        }
      }
    }
    
    trigger();
  }
  
  /**
   * Gets the value of the horizontal flag.<br>
   * If true the wall is horizontal, else vertical.
   */
  public boolean isHorizontal() {
    return horizontal;
  }
  
  /**
   * Sets the value of the horizontal flag.<br>
   * If true the wall is horizontal, else vertical.
   */
  public void setHorizontal(boolean h) {
    horizontal = h;
    setGrid();
  }
  
  /**
   * Gets the position of the wall.<br>
   * This is an x coordinate for a vertical wall, a y coordinate for a
   * horizontal one.
   */
  public double getPosition() {
    return pos;
  }
  
  /**
   * Sets the position of the wall.<br>
   * This is an x coordinate for a vertical wall, a y coordinate for a
   * horizontal one.
   */
  public void setPosition(double p) {
    pos = p;
    setGrid();
  }
  
  /**
   * Gets the wave velocity on the upper side (or right for a horizontal
   * splitting).
   */
  public double getUpperVelocity() {
    return cUp;
  }
  
  /**
   * Sets the wave velocity on the upper side (or right for a horizontal
   * splitting).
   */
  public void setUpperVelocity(double c) {
    cUp = c;
    setGrid();
  }
  
  /**
   * Gets the wave velocity on the lower side (or left for a horizontal
   * splitting).
   */
  public double getLowerVelocity() {
    return cLow;
  }
  
  /**
   * Sets the wave velocity on the lower side (or left for a horizontal
   * splitting).
   */
  public void setLowerVelocity(double c) {
    cLow = c;
    setGrid();
  }
}
