package physbeans.phys;

import java.io.*;
import physbeans.event.*;

/**
 * parent of all physical models.<br>
 * contains trigger support
 */
public class PhysModel implements Serializable {
  
  /** Creates a new instance of PhysModel */
  public PhysModel() {
    trigSup = new TriggerSupport();
  }
  
  // the usual support for Trigger events
  protected transient TriggerSupport trigSup;
  
  /** add a TriggerListener */
  public synchronized void addTriggerListener(TriggerListener l) {
    trigSup.addTriggerListener(l);
  }
  
  /** remove a TriggerListener */
  public synchronized void removeTriggerListener(TriggerListener l) {
    trigSup.removeTriggerListener(l);
  }
  
  /** fire a Trigger event */
  public void fireTriggerEvent(TriggerEvent e) {
    trigSup.fireTriggerEvent(e);
  }
  
  /**
   * Informs listeners of global changes.<br>
   * Useful, if a whole range of values has to be recomputed,
   *    f.i. after a parameter change.
   */
  public void trigger() {
    fireTriggerEvent(new TriggerEvent(this));
  }
}
